ExpandedGap class

A custom version of the Flexible widget that represents an expanded space within a flex_gap layout.

ExpandedGap is a convenience widget to simplify the addition of an expanded space in a flex_gap layout. It inherits from the Flexible widget with a FlexFit.tight configuration and a flex value of 1. This results in the child (or an empty Offstage widget by default) expanding to fill available space.

Advantages of using ExpandedGap:

  1. Simplicity: Provides a concise way to create an expanded space within a flex_gap layout.
  2. Configurability: Inherits the flexibility of the Flexible widget, allowing for customization of fit and flex parameters.
  3. flex_gap Integration: Seamlessly integrates with the flex_gap layout for a consistent spacing solution.
Inheritance

Constructors

ExpandedGap({Key? key, Widget? child})
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
debugTypicalAncestorWidgetClass → Type
Describes the RenderObjectWidget that is typically used to set up the ParentData that applyParentData will write to.
no setterinherited
debugTypicalAncestorWidgetDescription → String
Describes the RenderObjectWidget that is typically used to set up the ParentData that applyParentData will write to.
no setterinherited
fit → FlexFit
How a flexible child is inscribed into the available space.
finalinherited
flex → int
The flex factor to use for this child.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyParentData(RenderObject renderObject) → void
Write the data from this widget into the given render object's parent data.
inherited
createElement() → ParentDataElement<FlexParentData>
Inflates this configuration to a concrete instance.
inherited
debugCanApplyOutOfTurn() → bool
Whether the ParentDataElement.applyWidgetOutOfTurn method is allowed with this widget.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
debugIsValidRenderObject(RenderObject renderObject) → bool
Checks if this widget can apply its parent data to the provided renderObject.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited